pub struct EnvSecretsConfig { /* private fields */ }Expand description
Immutable logical-reference allowlist for one Plugin Instance.
Implementations
Sourceimpl EnvSecretsConfig
impl EnvSecretsConfig
Sourcepub fn insert(
&mut self,
reference: impl Into<String>,
environment_variable: impl Into<String>,
) -> Result<(), EnvSecretsConfigError>
pub fn insert( &mut self, reference: impl Into<String>, environment_variable: impl Into<String>, ) -> Result<(), EnvSecretsConfigError>
Adds one required logical reference and its environment source.
Sourcepub fn with_reference(
self,
reference: impl Into<String>,
environment_variable: impl Into<String>,
) -> Result<Self, EnvSecretsConfigError>
pub fn with_reference( self, reference: impl Into<String>, environment_variable: impl Into<String>, ) -> Result<Self, EnvSecretsConfigError>
Adds one required mapping through a consuming builder style.